@@ -1224,8 +1224,10 @@ GenericObserver::GenericObserver(QObject *parent)
     , m_save(nullptr)
     , m_finishAction(nullptr)
 {
-    QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
-    KGet::setHasNetworkConnection(QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online);
+    bool isBackendLoaded = QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
+    if (isBackendLoaded) {
+        KGet::setHasNetworkConnection(QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online);
+    }
 
     connect(KGet::model(), &TransferTreeModel::groupRemovedEvent, this, &GenericObserver::groupRemovedEvent);
     connect(KGet::model(), SIGNAL(transfersAddedEvent(QList<TransferHandler *>)), SLOT(transfersAddedEvent(QList<TransferHandler *>)));
@@ -1239,7 +1241,9 @@ GenericObserver::GenericObserver(QObject *parent)
             SLOT(groupsChangedEvent(QMap<TransferGroupHandler *, TransferGroup::ChangesFlags>)));
     connect(KGet::model(), &TransferTreeModel::transferMovedEvent, this, &GenericObserver::transferMovedEvent);
 
-    connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &GenericObserver::slotNetworkStatusChanged);
+    if (isBackendLoaded) {
+        connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &GenericObserver::slotNetworkStatusChanged);
+    }
 }
 
 GenericObserver::~GenericObserver()
