@@ -13,23 +13,23 @@
 
 #include "core/kget.h"
 #include "core/plugin/transferfactory.h"
-#include "core/transferhandler.h"
 #include "core/transfergrouphandler.h"
+#include "core/transferhandler.h"
 #include <QMenu>
 #include <QWidgetAction>
 
 #include <KFileItem>
-#include <KFileItemListProperties>
 #include <KFileItemActions>
+#include <KFileItemListProperties>
 
-QMenu * ContextMenu::createTransferContextMenu(QList<TransferHandler*> transfers, QWidget *parent)
+QMenu *ContextMenu::createTransferContextMenu(QList<TransferHandler *> transfers, QWidget *parent)
 {
     if (transfers.empty())
         return nullptr;
 
-    //First check whether all the transfers in the list belong to the same 
-    //transferfactory
-    //bool sameFactory = true;
+    // First check whether all the transfers in the list belong to the same
+    // transferfactory
+    // bool sameFactory = true;
 
     /*QList<TransferHandler *>::iterator it = transfers.begin();
     QList<TransferHandler *>::iterator itEnd = transfers.end();
@@ -42,36 +42,35 @@ QMenu * ContextMenu::createTransferContextMenu(QList<TransferHandler*> transfers
 
     auto *popup = new QMenu(parent);
     popup->addSection(transfers.first()->dest().fileName());
-    //Get the transfer factory actions
-    QList<QAction*> actionList = transfers.first()->factoryActions();
-//     popup->addSection( i18np("%1 Download selected", "%1 Downloads selected", transfers.count()) );
+    // Get the transfer factory actions
+    QList<QAction *> actionList = transfers.first()->factoryActions();
+    //     popup->addSection( i18np("%1 Download selected", "%1 Downloads selected", transfers.count()) );
 
-    //Plug all the actions in the popup menu
+    // Plug all the actions in the popup menu
     popup->addActions(transfers.first()->contextActions());
     popup->addSeparator();
-    popup->addAction( KGet::actionCollection()->action("transfer_settings") );
+    popup->addAction(KGet::actionCollection()->action("transfer_settings"));
     popup->addSeparator();
 
-    foreach (QAction * it, actionList)
-    {
-        //Plug each action in the popup menu
-        popup->addAction( it );
+    foreach (QAction *it, actionList) {
+        // Plug each action in the popup menu
+        popup->addAction(it);
     }
 
     if (!actionList.isEmpty())
         popup->addSeparator();
 
-    popup->addAction( KGet::actionCollection()->action("transfer_open_dest") );
-    //popup->addAction( KGet::actionCollection()->action("transfer_open_file") );
-    popup->addAction( KGet::actionCollection()->action("transfer_show_details") );
-    popup->addAction( KGet::actionCollection()->action("transfer_copy_source_url") );
+    popup->addAction(KGet::actionCollection()->action("transfer_open_dest"));
+    // popup->addAction( KGet::actionCollection()->action("transfer_open_file") );
+    popup->addAction(KGet::actionCollection()->action("transfer_show_details"));
+    popup->addAction(KGet::actionCollection()->action("transfer_copy_source_url"));
 
     return popup;
 }
 
-QMenu * ContextMenu::createTransferContextMenu(TransferHandler* handler, QWidget *parent)
+QMenu *ContextMenu::createTransferContextMenu(TransferHandler *handler, QWidget *parent)
 {
-    QMenu *popup = ContextMenu::createTransferContextMenu(QList<TransferHandler*>() << handler, parent);
+    QMenu *popup = ContextMenu::createTransferContextMenu(QList<TransferHandler *>() << handler, parent);
 
     // only shows the open with actions if the transfer is finished
     if (handler->status() == Job::Finished || handler->status() == Job::FinishedKeepAlive) {
@@ -96,12 +95,12 @@ QMenu * ContextMenu::createTransferContextMenu(TransferHandler* handler, QWidget
     return popup;
 }
 
-QMenu * ContextMenu::createTransferGroupContextMenu(TransferGroupHandler *handler, QWidget *parent)
+QMenu *ContextMenu::createTransferGroupContextMenu(TransferGroupHandler *handler, QWidget *parent)
 {
     if (!handler)
         return nullptr;
 
-    auto * popup = new QMenu(parent);
+    auto *popup = new QMenu(parent);
     popup->addSection(handler->name());
 
     popup->addActions(handler->actions());
@@ -120,6 +119,6 @@ QMenu * ContextMenu::createTransferGroupContextMenu(TransferGroupHandler *handle
         action->setText(i18np("Rename Group...", "Rename Groups...", numGroups));
         popup->addAction(action);
     }
-    popup->addAction( KGet::actionCollection()->action("seticon_groups") );
+    popup->addAction(KGet::actionCollection()->action("seticon_groups"));
     return popup;
 }
